@@ -1,12 +1,14 @@
 #' Internal function - generic downloader, used to serve the rds files from S3
 #'
+#' The function utilizes environment variable RCZECHIA_MIRROR as a mirror location of remote files; to configure an alternative (possibly local) repository use `Sys.setenv("RCZECHIA_MIRROR" = "a path")`
+#'
 #' @param file file to be downloaded (or not...) from S3
 #' @keywords internal
 
 .downloader <- function(file) {
   network <- as.logical(Sys.getenv("NETWORK_UP", unset = TRUE)) # dummy variable to allow testing of network
 
-  remote_path <- "https://rczechia.jla-data.net/" # remote archive
+  remote_path <- Sys.getenv("RCZECHIA_MIRROR", unset = "https://rczechia.jla-data.net/") # remote archive
 
   remote_file <- paste0(remote_path, file) # path to AWS S3
   local_file <- file.path(tempdir(), file) # local file - in tempdir
