@@ -10,10 +10,6 @@ test_that("chráněná území", {
   expect_message(chr_uzemi(), "internet") # zpráva o chybějícím internetu
   Sys.setenv("NETWORK_UP" = TRUE)
 
-  Sys.setenv("AWS_UP" = FALSE)
-  expect_message(chr_uzemi(), "source") # zpráva o spadlém AWS
-  Sys.setenv("AWS_UP" = TRUE)
-
   expect_true(is.data.frame(chr_uzemi()))
 
   expect_s3_class(chr_uzemi(), "sf")
